module.exports = defineTest({
	description: 'does not rename class methods incorrectly',
	options: {
		external: ['path']
	}
});
